DataDto class

Constructors

DataDto({String? apTransactionId, String? merchantKey, String? amount, int? transactionStatus, String? orderId, String? customVar, String? customerPhone, String? merchantId, int? transactionType, String? cardType, String? currencyCode, String? txnMode, String? token, String? uid, String? bankResponseMsg, String? transactionPaymentStatus, String? customerEmail, String? chmod, String? transactionTime, String? risk, String? apSecureHash, String? customerName, String? surchargeAmount})
DataDto.fromJson(Map<String, dynamic> json)

Properties

amount String?
getter/setter pair
apSecureHash String?
getter/setter pair
apTransactionId String?
getter/setter pair
bankResponseMsg String?
getter/setter pair
cardType String?
getter/setter pair
chmod String?
getter/setter pair
currencyCode String?
getter/setter pair
customerEmail String?
getter/setter pair
customerName String?
getter/setter pair
customerPhone String?
getter/setter pair
customVar String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
merchantId String?
getter/setter pair
merchantKey String?
getter/setter pair
orderId String?
getter/setter pair
risk String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surchargeAmount String?
getter/setter pair
token String?
getter/setter pair
transactionPaymentStatus String?
getter/setter pair
transactionStatus int?
getter/setter pair
transactionTime String?
getter/setter pair
transactionType int?
getter/setter pair
txnMode String?
getter/setter pair
uid String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited